# musicz_pygm
声明:
禁止将本项目代码用于ai训练
declaration:
Codes of this project are not allowed to be used for AI training or any other form of machine learning processes.

```
键盘按键弹钢琴的小程序
安装:
    pip install musicz_pygm

程序运行:
    python -m musicz_pygm 可选参数
    参数如下:
        [-f/--fp=]额外配置文件(没啥用)
        [-t/--default=]主要配置文件(默认预制的play.js)
        [-h/--help]
        [-b/--background] 添加背景音乐
    默认配置文件（key_music/conf目录下）：
        通用配置：
            shift和ctrl调整基调，方向键调整音量，esc和~退出，空格切音

        
```